var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { useState, useEffect } from 'react';
import AudioPlayer from './AudioPlayer';
export const playerSetupError = 'There was a problem setting up the player';
// @TODO make this a custom type for local/remote urls
const useAudioPlayer = (url) => {
    const [player, setPlayer] = useState({});
    const [status, setStatus] = useState({ loading: true });
    const [error, setError] = useState();
    useEffect(() => {
        function createPlayer() {
            return __awaiter(this, void 0, void 0, function* () {
                try {
                    // status updates will happen in the Player event bus
                    const nativePlayer = new AudioPlayer(url, setStatus);
                    // wait for player to be created before returning
                    yield nativePlayer.create();
                    if (nativePlayer.status.ready) {
                        setPlayer(nativePlayer);
                    }
                    // find a better way to handle this error
                    if (!nativePlayer.status.ready) {
                        setError(playerSetupError);
                    }
                }
                catch (err) {
                    setError(playerSetupError);
                }
            });
        }
        if (status.loading) {
            createPlayer();
        }
    }, [url, status]);
    // call on unmount
    useEffect(() => (() => {
        if (player.destroy) {
            // remove all listeners
            player.destroy();
        }
    }), [player]);
    const playerController = {
        status,
        seek: player.seek,
        toggleAudio: player.toggleAudio,
        seekForwards: player.seekForwards,
        seekBackwards: player.seekBackwards,
        destroy: player.destroy
    };
    return [playerController, error];
};
export default useAudioPlayer;
